@@ -36,7 +36,7 @@ class String
         :replace                     => '',        # Use a blank for those replacements
         :UNIVERSAL_NEWLINE_DECORATOR => true       # Always break lines with \n
       }
-      self.encode! Encoding.find('ASCII'), encoding_options
+      self.encode! Encoding.find('ASCII'), **encoding_options
     end
   end
 end
